from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.model_run_response_error import ModelRunResponseError


T = TypeVar("T", bound="ModelRunResponse")


@attr.s(auto_attribs=True)
class ModelRunResponse:
    """
    Attributes:
        slug (str): Short identifying name for the model Example: var.
        version (str): Version of the model Example: 1.0.
        chain_id (float): Chain id
        block_number (float): Block number
        dependencies (Dict[str, Any]): Dictionary of model dependencies, model name to version or version list. Example:
            {"x": "1.0", "y": ["2.0", "2.1"]}.
        cached (bool): Whether it is a cached result Example: True.
        runtime (float): Running time of the model in milliseconds. Example: 5100.
        output (Union[Unset, Dict[str, Any]]): Data generated by the model. An object, the contents of which are
            specific to the model. If the model run generated an error, this output property will not exist and an error
            property will exist. Example: { ... }.
        error (Union[Unset, ModelRunResponseError]):
    """

    slug: str
    version: str
    chain_id: float
    block_number: float
    dependencies: Dict[str, Any]
    cached: bool
    runtime: float
    output: Union[Unset, Dict[str, Any]] = UNSET
    error: Union[Unset, "ModelRunResponseError"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        slug = self.slug
        version = self.version
        chain_id = self.chain_id
        block_number = self.block_number
        dependencies = self.dependencies
        cached = self.cached
        runtime = self.runtime
        output = self.output
        error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "slug": slug,
                "version": version,
                "chainId": chain_id,
                "blockNumber": block_number,
                "dependencies": dependencies,
                "cached": cached,
                "runtime": runtime,
            }
        )
        if output is not UNSET:
            field_dict["output"] = output
        if error is not UNSET:
            field_dict["error"] = error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.model_run_response_error import ModelRunResponseError

        d = src_dict.copy()
        slug = d.pop("slug")

        version = d.pop("version")

        chain_id = d.pop("chainId")

        block_number = d.pop("blockNumber")

        dependencies = d.pop("dependencies")

        cached = d.pop("cached")

        runtime = d.pop("runtime")

        output = d.pop("output", UNSET)

        _error = d.pop("error", UNSET)
        error: Union[Unset, ModelRunResponseError]
        if isinstance(_error, Unset):
            error = UNSET
        else:
            error = ModelRunResponseError.from_dict(_error)

        model_run_response = cls(
            slug=slug,
            version=version,
            chain_id=chain_id,
            block_number=block_number,
            dependencies=dependencies,
            cached=cached,
            runtime=runtime,
            output=output,
            error=error,
        )

        model_run_response.additional_properties = d
        return model_run_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
